---
title: "Introduction"
description: "Automate browser tasks in plain text."
icon: "browser"
---

<img
  className="block dark:hidden rounded-2xl"
  src="/images/openbrowser-banner.svg"
  alt="OpenBrowser Banner"
/>
<img
  className="hidden dark:block rounded-2xl"
  src="/images/openbrowser-banner-dark.svg"
  alt="OpenBrowser Banner"
/>

<CardGroup cols={2}>
  <Card title="Quick Start" icon="terminal" href="/quickstart">
     Get started with OpenBrowser in minutes.
  </Card>
  <Card
    title="Supported Models"
    icon="brain"
    href="/supported-models"
    color="#0ea5e9"
  >
      See all supported LLM providers.
  </Card>
</CardGroup>
